@@ -1,5 +1,5 @@
 __author__ = 'Andrea De Marco <24erre@gmail.com>'
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 __classifiers__ = [
     'Development Status :: 4 - Beta',
     'Intended Audience :: Developers',
@@ -39,6 +39,13 @@ __doc__ = """
 """ % (__version__, __author__, __license__)
 
 import logging
+try:
+    from logging import NullHandler
+except ImportError:
+    class NullHandler(logging.Handler):
+        def emit(self, record):
+            pass
+logging.getLogger(__name__).addHandler(NullHandler())
 
 LOG_LEVELS = {
     'critical': logging.CRITICAL,
@@ -51,11 +58,8 @@ LOG_LEVELS = {
 def set_logging(level, handler=None):
     if not handler:
         handler = logging.StreamHandler()
-    format = r'[%(levelname)s] %(message)s'
-    handler.setFormatter(logging.Formatter(format))
-    loggers = [
-        logging.getLogger('rtkit'),
-    ]
-    for logger in loggers:
-        logger.setLevel(LOG_LEVELS.get(level, logging.INFO))
-        logger.addHandler(handler)
\ No newline at end of file
+    fmt = r'[%(levelname)s] %(message)s'
+    handler.setFormatter(logging.Formatter(fmt))
+    logger = logging.getLogger(__name__)
+    logger.setLevel(LOG_LEVELS.get(level, logging.INFO))
+    logger.addHandler(handler)
